==> craftedcore-fabric-1.20.2-5.6-sources.jar: tocraft/craftedcore/patched/client/CGraphics.java <==
package tocraft.craftedcore.patched.client;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_1921;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;

@SuppressWarnings("unused")
@Environment(EnvType.CLIENT)
public class CGraphics {
    //#if MC>=1212
    public static void blit(class_332 graphics, class_2960 atlasLocation, int x, int y, int width, int height, int uOffset, int vOffset, int uWidth, int vHeight, int textureWidth, int textureHeight) {
        graphics.method_25297(class_1921::guiTextured, atlasLocation, x, y, width, height, uOffset, vOffset, uWidth, vHeight, textureWidth, textureHeight);
    }
    
    public static void blit(class_332 graphics, int x, int y, int blitOffset, int width, int height, class_1058 sprite) {
        graphics.method_52710(class_1921::guiTextured, sprite, x, y, blitOffset, width, height);
    }
    
    public static void fillTransparent(class_332 graphics, int x1, int y1, int x2, int y2) {
        fillGradient(graphics, x1, y1, x2, y2, -1072689136, -804253680);
    }
    
    public static void fillGradient(class_332 graphics, int x1, int y1, int x2, int y2, int colorFrom, int colorTo) {
        graphics.method_25296(x1, y1, x2, y2, colorFrom, colorTo);
    }
    
    public static void drawString(class_332 context, class_2561 text, int i, int j, int k, boolean bl) {
        context.method_51439(class_310.method_1551().field_1772, text, i, j, k, bl);
    }
    //#elseif MC>1194
    //$$ public static void blit(GuiGraphics graphics, ResourceLocation atlasLocation, int x, int y, int width, int height, float uOffset, float vOffset, int uWidth, int vHeight, int textureWidth, int textureHeight) {
    //$$     graphics.blit(atlasLocation, x, y, width, height, uOffset, vOffset, uWidth, vHeight, textureWidth, textureHeight);
    //$$ }
    //$$
    //$$ public static void blit(GuiGraphics graphics, int x, int y, int blitOffset, int width, int height, TextureAtlasSprite sprite) {
    //$$     graphics.blit(x, y, blitOffset, width, height, sprite);
    //$$ }
    //$$
    //$$ public static void fillTransparent(GuiGraphics graphics, int x1, int y1, int x2, int y2) {
    //$$     fillGradient(graphics, x1, y1, x2, y2, -1072689136, -804253680);
    //$$ }
    //$$
    //$$ public static void fillGradient(GuiGraphics graphics, int x1, int y1, int x2, int y2, int colorFrom, int colorTo) {
    //$$     graphics.fillGradient(x1, y1, x2, y2, colorFrom, colorTo);
    //$$ }
    //$$
    //$$ public static void drawString(GuiGraphics context, Component text, int i, int j, int k, boolean bl) {
    //$$     context.drawString(Minecraft.getInstance().font, text, i, j, k, bl);
    //$$ }
    //$$
    //#else
    //$$ public static void blit(PoseStack graphics, ResourceLocation atlasLocation, int x, int y, int width, int height, float uOffset, float vOffset, int uWidth, int vHeight, int textureWidth, int textureHeight) {
    //$$     RenderSystem.setShaderTexture(0, atlasLocation);
    //$$     GuiComponent.blit(graphics, x, y, width, height, uOffset, vOffset, uWidth, vHeight, textureWidth, textureHeight);
    //$$ }
    //$$
    //$$ public static void fillTransparent(PoseStack graphics, int x1, int y1, int x2, int y2) {
    //$$     fillGradient(graphics, x1, y1, x2, y2, -1072689136, -804253680);
    //$$ }
    //$$
    //$$ public static void fillGradient(PoseStack poseStack, int x1, int y1, int x2, int y2, int colorFrom, int colorTo) {
    //$$     fillGradient(poseStack, x1, y1, x2, y2, colorFrom, colorTo, 0);
    //$$ }
    //$$
    //$$ @SuppressWarnings("SameParameterValue")
    //$$ private static void fillGradient(PoseStack poseStack, int x1, int y1, int x2, int y2, int colorFrom, int colorTo, int blitOffset) {
    //$$     RenderSystem.enableBlend();
    //$$     RenderSystem.setShader(GameRenderer::getPositionColorShader);
    //$$     Tesselator tesselator = Tesselator.getInstance();
    //$$     BufferBuilder bufferBuilder = tesselator.getBuilder();
    //$$     bufferBuilder.begin(VertexFormat.Mode.QUADS, DefaultVertexFormat.POSITION_COLOR);
    //$$     fillGradient(poseStack.last().pose(), bufferBuilder, x1, y1, x2, y2, blitOffset, colorFrom, colorTo);
    //$$     tesselator.end();
    //$$     RenderSystem.disableBlend();
    //$$ }
    //$$
    //$$ private static void fillGradient(Matrix4f matrix, BufferBuilder builder, int x1, int y1, int x2, int y2, int blitOffset, int colorA, int colorB) {
    //$$     float f = (float) FastColor.ARGB32.alpha(colorA) / 255.0F;
    //$$     float g = (float) FastColor.ARGB32.red(colorA) / 255.0F;
    //$$     float h = (float) FastColor.ARGB32.green(colorA) / 255.0F;
    //$$     float i = (float) FastColor.ARGB32.blue(colorA) / 255.0F;
    //$$     float j = (float) FastColor.ARGB32.alpha(colorB) / 255.0F;
    //$$     float k = (float) FastColor.ARGB32.red(colorB) / 255.0F;
    //$$     float l = (float) FastColor.ARGB32.green(colorB) / 255.0F;
    //$$     float m = (float) FastColor.ARGB32.blue(colorB) / 255.0F;
    //$$     builder.vertex(matrix, (float) x1, (float) y1, (float) blitOffset).color(g, h, i, f).endVertex();
    //$$     builder.vertex(matrix, (float) x1, (float) y2, (float) blitOffset).color(k, l, m, j).endVertex();
    //$$     builder.vertex(matrix, (float) x2, (float) y2, (float) blitOffset).color(k, l, m, j).endVertex();
    //$$     builder.vertex(matrix, (float) x2, (float) y1, (float) blitOffset).color(g, h, i, f).endVertex();
    //$$ }
    //$$
    //$$     public static void drawString(PoseStack context, Component text, int i, int j, int k, boolean bl) {
    //$$         Minecraft.getInstance().font.drawShadow(context, text.getString(), i, j, k, bl);
    //$$     }
    //$$
    //$$     public static void blit(PoseStack graphics, int x, int y, int blitOffset, int width, int height, TextureAtlasSprite sprite) {
            //#if MC>1182
            //$$ RenderSystem.setShaderTexture(0, sprite.atlasLocation());
            //#else
            //$$ RenderSystem.setShaderTexture(0, sprite.atlas().location());
            //#endif
    //$$         GuiComponent.blit(graphics, x, y, blitOffset, width, height, sprite);
    //$$     }
    //#endif
}

==> craftedcore-fabric-1.21-5.5-sources.jar: tocraft/craftedcore/patched/client/CGraphics.java <==
package tocraft.craftedcore.patched.client;

import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.minecraft.class_1058;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_332;

@SuppressWarnings("unused")
@Environment(EnvType.CLIENT)
public class CGraphics {
    //#if MC>1194
    public static void blit(class_332 graphics, class_2960 texture, int i, int j, int k, int l, float f, float g, int m, int n, int o, int p) {
        graphics.method_25293(texture, i, j, k, l, f, g, m, n, o, p);
    }
    
    public static void blit(class_332 graphics, int i, int j, int k, int l, int m, class_1058 textureAtlasSprite) {
        graphics.method_25298(i, j, k, l, m, textureAtlasSprite);
    }
    
    public static void fillTransparent(class_332 graphics, int x1, int y1, int x2, int y2) {
        fillGradient(graphics, x1, y1, x2, y2, -1072689136, -804253680);
    }
    
    public static void fillGradient(class_332 graphics, int x1, int y1, int x2, int y2, int colorFrom, int colorTo) {
        graphics.method_25296(x1, y1, x2, y2, colorFrom, colorTo);
    }
    
    public static void drawString(class_332 context, class_2561 text, int i, int j, int k, boolean bl) {
        context.method_51439(class_310.method_1551().field_1772, text, i, j, k, bl);
    }
    
    //#else
    //$$ public static void blit(PoseStack graphics, ResourceLocation texture, int i, int j, int k, int l, float f, float g, int m, int n, int o, int p) {
    //$$     RenderSystem.setShaderTexture(0, texture);
    //$$     GuiComponent.blit(graphics, i, j, k, l, f, g, m, n, o, p);
    //$$ }
    //$$
    //$$ public static void fillTransparent(PoseStack graphics, int x1, int y1, int x2, int y2) {
    //$$     fillGradient(graphics, x1, y1, x2, y2, -1072689136, -804253680);
    //$$ }
    //$$
    //$$ public static void fillGradient(PoseStack poseStack, int x1, int y1, int x2, int y2, int colorFrom, int colorTo) {
    //$$     fillGradient(poseStack, x1, y1, x2, y2, colorFrom, colorTo, 0);
    //$$ }
    //$$
    //$$ @SuppressWarnings("SameParameterValue")
    //$$ private static void fillGradient(PoseStack poseStack, int x1, int y1, int x2, int y2, int colorFrom, int colorTo, int blitOffset) {
    //$$     RenderSystem.enableBlend();
    //$$     RenderSystem.setShader(GameRenderer::getPositionColorShader);
    //$$     Tesselator tesselator = Tesselator.getInstance();
    //$$     BufferBuilder bufferBuilder = tesselator.getBuilder();
    //$$     bufferBuilder.begin(VertexFormat.Mode.QUADS, DefaultVertexFormat.POSITION_COLOR);
    //$$     fillGradient(poseStack.last().pose(), bufferBuilder, x1, y1, x2, y2, blitOffset, colorFrom, colorTo);
    //$$     tesselator.end();
    //$$     RenderSystem.disableBlend();
    //$$ }
    //$$
    //$$ private static void fillGradient(Matrix4f matrix, BufferBuilder builder, int x1, int y1, int x2, int y2, int blitOffset, int colorA, int colorB) {
    //$$     float f = (float) FastColor.ARGB32.alpha(colorA) / 255.0F;
    //$$     float g = (float) FastColor.ARGB32.red(colorA) / 255.0F;
    //$$     float h = (float) FastColor.ARGB32.green(colorA) / 255.0F;
    //$$     float i = (float) FastColor.ARGB32.blue(colorA) / 255.0F;
    //$$     float j = (float) FastColor.ARGB32.alpha(colorB) / 255.0F;
    //$$     float k = (float) FastColor.ARGB32.red(colorB) / 255.0F;
    //$$     float l = (float) FastColor.ARGB32.green(colorB) / 255.0F;
    //$$     float m = (float) FastColor.ARGB32.blue(colorB) / 255.0F;
    //$$     builder.vertex(matrix, (float) x1, (float) y1, (float) blitOffset).color(g, h, i, f).endVertex();
    //$$     builder.vertex(matrix, (float) x1, (float) y2, (float) blitOffset).color(k, l, m, j).endVertex();
    //$$     builder.vertex(matrix, (float) x2, (float) y2, (float) blitOffset).color(k, l, m, j).endVertex();
    //$$     builder.vertex(matrix, (float) x2, (float) y1, (float) blitOffset).color(g, h, i, f).endVertex();
    //$$ }
    //$$
    //$$     public static void drawString(PoseStack context, Component text, int i, int j, int k, boolean bl) {
    //$$         Minecraft.getInstance().font.drawShadow(context, text.getString(), i, j, k, bl);
    //$$     }
    //$$
    //$$     public static void blit(PoseStack graphics, int i, int j, int k, int l, int m, TextureAtlasSprite textureAtlasSprite) {
            //#if MC>1182
            //$$ RenderSystem.setShaderTexture(0, textureAtlasSprite.atlasLocation());
            //#else
            //$$ RenderSystem.setShaderTexture(0, textureAtlasSprite.atlas().location());
            //#endif
    //$$         GuiComponent.blit(graphics, i, j, k, l, m, textureAtlasSprite);
    //$$     }
    //#endif
}
